import React, { useState } from 'react';
import {
  Card,
  CardContent,
} from '@/components/ui/card';
import { Button } from '@/components/ui/button';
import { Input } from '@/components/ui/input';
import { Label } from '@/components/ui/label';
import { RadioGroup, RadioGroupItem } from '@/components/ui/radio-group';
import { usePriceCalculator } from '@/hooks/use-price-calculator';
import {
  Dialog,
  DialogContent,
  DialogHeader,
  DialogTitle,
  DialogDescription,
  DialogFooter,
} from '@/components/ui/dialog';
import { Textarea } from '@/components/ui/textarea';
import { apiRequest } from '@/lib/queryClient';
import { useToast } from '@/hooks/use-toast';
import { motion } from 'framer-motion';
import CarSelect from '@/components/ui/car-select';
import CarColorPreview from '@/components/car-color-preview';
import { Checkbox } from '@/components/ui/checkbox';
import { WhatsAppButton } from '@/components/whatsapp-button';

const PriceCalculator: React.FC = () => {
  const { toast } = useToast();
  const [inquiryDialogOpen, setInquiryDialogOpen] = useState(false);
  const [formData, setFormData] = useState({
    name: '',
    email: '',
    phone: '',
    message: '',
  });
  
  const [isSubmitting, setIsSubmitting] = useState(false);

  const {
    selectedClass,
    setSelectedClass,
    selectedModel,
    setSelectedModel,
    customModel,
    setCustomModel,
    selectedPackage,
    setSelectedPackage,
    calculatedPrice,
    getPackageName,
    includeHeadlights,
    setIncludeHeadlights,
    headlightsPrice,
    handleColorPriceChange
  } = usePriceCalculator();

  const handleSubmitInquiry = async (e: React.FormEvent) => {
    e.preventDefault();
    
    if (!selectedPackage) {
      toast({
        title: document.documentElement.lang === 'ru' ? "Ошибка" : "Viga",
        description: document.documentElement.lang === 'ru' 
          ? "Пожалуйста, выберите вариант защиты" 
          : "Palun valige paketi tüüp",
        variant: "destructive",
      });
      return;
    }
    
    // For headlights_protection we don't need a car class
    if (selectedPackage !== 'headlights_protection' && !selectedClass) {
      toast({
        title: document.documentElement.lang === 'ru' ? "Ошибка" : "Viga",
        description: document.documentElement.lang === 'ru' 
          ? "Пожалуйста, выберите модель автомобиля" 
          : "Palun valige auto mudel",
        variant: "destructive",
      });
      return;
    }
    
    setIsSubmitting(true);
    
    try {
      const modelName = customModel || selectedModel || (selectedPackage === 'headlights_protection' ? 'Esitulede kaitse' : 'Auto');
      
      await apiRequest('POST', '/api/inquiries', {
        name: formData.name,
        email: formData.email,
        phone: formData.phone,
        message: formData.message,
        carClass: selectedPackage === 'headlights_protection' ? 0 : parseInt(selectedClass),
        carModel: modelName,
        serviceType: getPackageName(selectedPackage),
        price: `${calculatedPrice} €`,
      });
      
      toast({
        title: document.documentElement.lang === 'ru' 
          ? "Спасибо за ваш запрос!" 
          : "Täname teid päringu eest!",
        description: document.documentElement.lang === 'ru' 
          ? "Мы свяжемся с вами в ближайшее время." 
          : "Võtame teiega peagi ühendust.",
      });
      
      setInquiryDialogOpen(false);
      setFormData({
        name: '',
        email: '',
        phone: '',
        message: '',
      });
    } catch (error) {
      toast({
        title: document.documentElement.lang === 'ru' ? "Ошибка" : "Viga",
        description: document.documentElement.lang === 'ru' 
          ? "Не удалось отправить запрос. Пожалуйста, попробуйте позже." 
          : "Päringu saatmine ebaõnnestus. Palun proovige hiljem uuesti.",
        variant: "destructive",
      });
    } finally {
      setIsSubmitting(false);
    }
  };

  return (
    <section id="hinnakiri" className="py-16 bg-accent">
      <div className="container mx-auto px-4">
        <div className="text-center mb-12">
          <h2 className="text-3xl font-bold mb-4">
            {/* Use the useLanguage hook but directly here to avoid rerendering issues */}
            {document.documentElement.lang === 'ru' 
              ? "Онлайн-калькулятор стоимости антигравийной защиты" 
              : "Arvuta oma auto kiletamise hind"}
          </h2>
          <p className="text-gray-600 max-w-3xl mx-auto">
            {document.documentElement.lang === 'ru' 
              ? "Выберите марку и модель вашего автомобиля и вариант защитной пленки PPF для мгновенного расчета стоимости. Наши цены включают работу и материалы." 
              : "Vali oma auto mudel ja sobiv kiletusvõimalus, et näha kohe hinnapakkumist."}
          </p>
        </div>
        
        <motion.div
          initial={{ opacity: 0, y: 20 }}
          whileInView={{ opacity: 1, y: 0 }}
          viewport={{ once: true }}
          transition={{ duration: 0.5 }}
        >
          <Card className="bg-white p-8 rounded-lg shadow-md max-w-4xl mx-auto">
            <CardContent className="p-0">
              <div className="grid grid-cols-1 md:grid-cols-2 gap-8">
                <div>
                  <h3 className="text-xl font-medium mb-4">
                    {document.documentElement.lang === 'ru' 
                      ? "1. Выберите марку и модель авто" 
                      : "1. Vali auto mudel"}
                  </h3>
                  <div className="space-y-4">
                    <div>
                      <Label htmlFor="carModel" className="block text-sm font-medium text-gray-700 mb-1">
                        {document.documentElement.lang === 'ru' 
                          ? "Марка и модель автомобиля" 
                          : "Auto mudel"}
                      </Label>
                      <CarSelect
                        value={selectedModel}
                        onValueChange={(value, carClass) => {
                          setSelectedModel(value);
                          setSelectedClass(carClass);
                          if (value) setCustomModel('');
                        }}
                      />
                    </div>
                    
                    <div>
                      <Label htmlFor="customCarModel" className="block text-sm font-medium text-gray-700 mb-1">
                        {document.documentElement.lang === 'ru' 
                          ? "Или введите вашу модель вручную" 
                          : "Või sisesta oma auto mudel"}
                      </Label>
                      <Input
                        id="customCarModel"
                        value={customModel}
                        onChange={(e) => {
                          setCustomModel(e.target.value);
                          if (e.target.value) {
                            setSelectedModel('');
                            // Default to class 3 for custom cars if no class was selected before
                            if (!selectedClass) {
                              setSelectedClass('3');
                            }
                          }
                        }}
                        placeholder={document.documentElement.lang === 'ru' 
                          ? "Напр. Audi Q7 2022, BMW X5, Mercedes GLE" 
                          : "Nt. Audi Q7 2022"}
                      />
                    </div>
                  </div>
                </div>
                
                <div>
                  <h3 className="text-xl font-medium mb-4">
                    {document.documentElement.lang === 'ru' 
                      ? "2. Выберите вариант защиты кузова" 
                      : "2. Vali paketi tüüp"}
                  </h3>
                  <RadioGroup
                    value={selectedPackage}
                    onValueChange={setSelectedPackage}
                    className="space-y-3"
                  >
                    <div className="flex items-center space-x-2 p-3 border rounded-md hover:border-primary transition-colors cursor-pointer">
                      <RadioGroupItem value="full" id="package_full" />
                      <div className="grid gap-1.5">
                        <Label htmlFor="package_full" className="font-medium cursor-pointer">
                          {document.documentElement.lang === 'ru' 
                            ? "Полная антигравийная защита кузова" 
                            : "Täielik kiletamine"}
                        </Label>
                        <p className="text-sm text-gray-600">
                          {document.documentElement.lang === 'ru' 
                            ? "Комплексная защита всего кузова премиальной пленкой PPF" 
                            : "Kogu auto kere kaitsekile"}
                        </p>
                      </div>
                    </div>
                    
                    <div className="flex items-center space-x-2 p-3 border rounded-md hover:border-primary transition-colors cursor-pointer">
                      <RadioGroupItem value="partial" id="package_partial" />
                      <div className="grid gap-1.5">
                        <Label htmlFor="package_partial" className="font-medium cursor-pointer">
                          {document.documentElement.lang === 'ru' 
                            ? "Частичная защита кузова" 
                            : "Osaline kiletamine"}
                        </Label>
                        <p className="text-sm text-gray-600">
                          {document.documentElement.lang === 'ru' 
                            ? "Капот, зеркала, фары, бамперы и другие зоны риска" 
                            : "Kapott, peeglid, esilaternad, põrkerauad"}
                        </p>
                      </div>
                    </div>
                    
                    <div className="flex items-center space-x-2 p-3 border rounded-md hover:border-primary transition-colors cursor-pointer">
                      <RadioGroupItem value="risk" id="package_risk" />
                      <div className="grid gap-1.5">
                        <Label htmlFor="package_risk" className="font-medium cursor-pointer">
                          {document.documentElement.lang === 'ru' 
                            ? "Защита зон риска \"Стандарт\"" 
                            : "Riskitsoonid \"Standard\""}
                        </Label>
                        <p className="text-sm text-gray-600">
                          {document.documentElement.lang === 'ru' 
                            ? "Передний бампер, капот, зеркала, фары" 
                            : "Esiosa, peeglid, esituled"}
                        </p>
                      </div>
                    </div>
                    
                    <div className="flex items-center space-x-2 p-3 border rounded-md hover:border-primary transition-colors cursor-pointer">
                      <RadioGroupItem value="premium" id="package_premium" />
                      <div className="grid gap-1.5">
                        <Label htmlFor="package_premium" className="font-medium cursor-pointer">
                          {document.documentElement.lang === 'ru' 
                            ? "Защита зон риска \"Премиум\"" 
                            : "Riskitsoonid \"Premium\""}
                        </Label>
                        <p className="text-sm text-gray-600">
                          {document.documentElement.lang === 'ru' 
                            ? "Передний бампер, капот, зеркала, фары, пороги, задний бампер" 
                            : "Esiosa, peeglid, esituled, lävepakud, pagasiluuk"}
                        </p>
                      </div>
                    </div>

                    <div className="flex items-center space-x-2 p-3 border rounded-md hover:border-primary transition-colors cursor-pointer">
                      <RadioGroupItem value="bumpers" id="package_bumpers" />
                      <div className="grid gap-1.5">
                        <Label htmlFor="package_bumpers" className="font-medium cursor-pointer">
                          {document.documentElement.lang === 'ru' 
                            ? "Антигравийная защита бамперов" 
                            : "Põrkeraudade kaitsekile"}
                        </Label>
                        <p className="text-sm text-gray-600">
                          {document.documentElement.lang === 'ru' 
                            ? "Полная защита переднего и заднего бамперов от сколов и царапин" 
                            : "Esi- ja tagakaitserauad täielikult"}
                        </p>
                      </div>
                    </div>
                    
                    <div className="flex items-center space-x-2 p-3 border rounded-md hover:border-primary transition-colors cursor-pointer">
                      <RadioGroupItem value="headlights_protection" id="package_headlights" />
                      <div className="grid gap-1.5">
                        <Label htmlFor="package_headlights" className="font-medium cursor-pointer">
                          {document.documentElement.lang === 'ru' 
                            ? "Защита фар от повреждений" 
                            : "Esitulede kaitsekile"}
                        </Label>
                        <p className="text-sm text-gray-600">
                          {document.documentElement.lang === 'ru' 
                            ? "Защитная пленка на обе фары, фиксированная цена 90€" 
                            : "Mõlemad esituled, fikseeritud hind 90€"}
                        </p>
                      </div>
                    </div>
                  </RadioGroup>
                </div>
              </div>
              
              <div className="mt-8 p-6 bg-accent rounded-md">
                <div className="flex justify-between items-center">
                  <div>
                    <h3 className="text-xl font-medium">
                      {selectedPackage ? getPackageName(selectedPackage) : 
                        (document.documentElement.lang === 'ru' ? "Выберите комплект защиты" : "Vali paket")}
                    </h3>
                    <p className="text-gray-600">
                      {customModel || selectedModel || 
                        (document.documentElement.lang === 'ru' ? "Выберите модель автомобиля" : "Vali auto mudel")}
                    </p>
                  </div>
                  <div className="text-right">
                    <div className="text-3xl font-bold text-primary">
                      {calculatedPrice} €
                    </div>
                    <p className="text-sm text-gray-500">
                      {document.documentElement.lang === 'ru' ? "Итоговая цена с учетом НДС" : "Hind sisaldab käibemaksu"}
                    </p>
                  </div>
                </div>
                
                <div className="mt-6 grid grid-cols-1 sm:grid-cols-2 gap-3">
                  <Button 
                    className="w-full bg-primary hover:bg-primary/90" 
                    size="lg"
                    onClick={() => {
                      if (!selectedPackage) {
                        toast({
                          title: document.documentElement.lang === 'ru' ? "Ошибка" : "Viga",
                          description: document.documentElement.lang === 'ru' 
                            ? "Пожалуйста, выберите комплект защиты" 
                            : "Palun valige paketi tüüp",
                          variant: "destructive",
                        });
                        return;
                      }
                      
                      // For headlights_protection we don't need a car class
                      if (selectedPackage !== 'headlights_protection' && !selectedClass) {
                        toast({
                          title: document.documentElement.lang === 'ru' ? "Ошибка" : "Viga",
                          description: document.documentElement.lang === 'ru' 
                            ? "Пожалуйста, выберите модель автомобиля" 
                            : "Palun valige auto mudel",
                          variant: "destructive",
                        });
                        return;
                      }
                      
                      setInquiryDialogOpen(true);
                    }}
                  >
                    {document.documentElement.lang === 'ru' 
                      ? "Получить персональное предложение" 
                      : "Küsi pakkumist"}
                  </Button>
                  
                  <WhatsAppButton
                    phoneNumber="+37258743963"
                    message={document.documentElement.lang === 'ru' 
                      ? `Здравствуйте! Интересует комплект защиты "${selectedPackage ? getPackageName(selectedPackage) : ""}". Автомобиль: ${customModel || selectedModel || ""}. Расчетная стоимость: ${calculatedPrice}€` 
                      : `Tere! Soovin konsultatsiooni ${selectedPackage ? getPackageName(selectedPackage) : ""} teenuse kohta. Auto: ${customModel || selectedModel || ""}. Hinnapakkumine: ${calculatedPrice}€`}
                    size="lg"
                    className="w-full"
                  >
                    {document.documentElement.lang === 'ru' 
                      ? "Консультация в WhatsApp" 
                      : "WhatsApp konsultatsioon"}
                  </WhatsAppButton>
                </div>
              </div>
            </CardContent>
          </Card>
        </motion.div>
      </div>
      
      <Dialog open={inquiryDialogOpen} onOpenChange={setInquiryDialogOpen}>
        <DialogContent className="sm:max-w-[425px]">
          <DialogHeader>
            <DialogTitle>
              {document.documentElement.lang === 'ru' 
                ? "Получить персональное предложение по защите вашего автомобиля" 
                : "Küsi pakkumist"}
            </DialogTitle>
            <DialogDescription>
              {document.documentElement.lang === 'ru' 
                ? "Заполните форму для получения детального коммерческого предложения с точной стоимостью и сроками. Мы свяжемся с вами в течение 2 часов в рабочее время." 
                : "Täitke vorm ja me võtame teiega esimesel võimalusel ühendust."}
            </DialogDescription>
          </DialogHeader>
          
          <form onSubmit={handleSubmitInquiry}>
            <div className="grid gap-4 py-4">
              <div className="grid gap-2">
                <Label htmlFor="name">
                  {document.documentElement.lang === 'ru' ? "Ваше имя" : "Nimi"}
                </Label>
                <Input
                  id="name"
                  value={formData.name}
                  onChange={(e) => setFormData({ ...formData, name: e.target.value })}
                  required
                />
              </div>
              
              <div className="grid gap-2">
                <Label htmlFor="email">
                  {document.documentElement.lang === 'ru' ? "Электронная почта" : "E-mail"}
                </Label>
                <Input
                  id="email"
                  type="email"
                  value={formData.email}
                  onChange={(e) => setFormData({ ...formData, email: e.target.value })}
                  required
                />
              </div>
              
              <div className="grid gap-2">
                <Label htmlFor="phone">
                  {document.documentElement.lang === 'ru' ? "Контактный телефон" : "Telefoninumber"}
                </Label>
                <Input
                  id="phone"
                  type="tel"
                  value={formData.phone}
                  onChange={(e) => setFormData({ ...formData, phone: e.target.value })}
                  required
                />
              </div>
              
              <div className="grid gap-2">
                <Label htmlFor="message">
                  {document.documentElement.lang === 'ru' 
                    ? "Дополнительная информация или вопросы (опционально)" 
                    : "Lisainfo (valikuline)"}
                </Label>
                <Textarea
                  id="message"
                  value={formData.message}
                  onChange={(e) => setFormData({ ...formData, message: e.target.value })}
                  rows={3}
                />
              </div>
              
              <div className="bg-accent p-4 rounded-md mt-2">
                <div className="font-medium">
                  {document.documentElement.lang === 'ru' ? "Выбранный комплект защиты:" : "Valitud teenus:"}
                </div>
                <div className="text-gray-600">
                  {selectedPackage ? getPackageName(selectedPackage) : ""}
                </div>
                <div className="font-medium mt-2">
                  {document.documentElement.lang === 'ru' ? "Марка и модель вашего автомобиля:" : "Teie auto:"}
                </div>
                <div className="text-gray-600">
                  {customModel || selectedModel || ""}
                </div>
                <div className="font-medium mt-2">
                  {document.documentElement.lang === 'ru' ? "Предварительная стоимость:" : "Hind:"}
                </div>
                <div className="text-xl font-bold text-primary">
                  {calculatedPrice} €
                </div>
              </div>
            </div>
            
            <DialogFooter>
              <Button type="submit" disabled={isSubmitting}>
                {isSubmitting 
                  ? (document.documentElement.lang === 'ru' ? "Отправка запроса..." : "Saadan...") 
                  : (document.documentElement.lang === 'ru' ? "Отправить запрос на расчет" : "Saada pakkumine")}
              </Button>
            </DialogFooter>
          </form>
        </DialogContent>
      </Dialog>
    </section>
  );
};

export default PriceCalculator;
